@@ -9,12 +9,20 @@
 #include <validator/resolver.h>
 #include <validator/validator.h>
 
+#include <sys/types.h>
+#include <sys/socket.h>
+#include <netdb.h>
+
 #include <QtGui/QGridLayout>
 #include <QtGui/QVBoxLayout>
 #include <QtGui/QLabel>
 #include <QtGui/QPushButton>
+#include <QtGui/QLineEdit>
+
+#include <QtNetwork/QNetworkAccessManager>
 
 #include "QStatusLight.h"
+#include "TestManager.h"
 
 #if (defined(Q_WS_MAEMO_5) || defined(MAEMO_CHANGES))
 #define SMALL_DEVICE 1
@@ -41,14 +49,21 @@ public:
     void setupWidgets();
     void setupMenus();
     void loadResolvConf();
+    void addAddress(QString address, int row = -1);
 
 public slots:
+    void startGetAnswers();
     void getAnswers();
     void getSubAnswers();
     void showAbout();
     void showResultDetails();
+    void maybeSubmitResults();
+    void submitResults(QString locationDescription = "");
+    void addLineAddress();
+    void responseReceived(QNetworkReply *response);
 
 private:
+    TestManager  m_testManager;
     QStringList  m_serverAddresses;
 
     QWidget     *m_mainWidget;
@@ -64,6 +79,12 @@ private:
     QList<QStatusLight *> m_tests;
 
     QStatusLight *m_testResult;
+    QLineEdit    *m_lineEdit;
+
+    int m_rows;
+    QNetworkAccessManager *m_manager;
+    QAction *m_detailedResults;
+    QAction *m_submitResults;
 };
 
 #endif // MAINWINDOW_H
